@@ -28,6 +28,8 @@
 /* Default settings */
 #define GENERAL_HIDE_FROM_TASKBAR       TRUE
 #define GENERAL_SHOW_TABS               FALSE
+#define GENERAL_SHOW_NAVBAR             TRUE
+#define GENERAL_TABS_POSITION           0
 #define GENERAL_HIDE_ARROW_BUTTON       FALSE
 #define GENERAL_BACKGROUND_COLOR        BACKGROUND_YELLOW
 #define NEW_WINDOW_ABOVE                FALSE
@@ -35,7 +37,7 @@
 #define NEW_WINDOW_TABS                 TRUE
 #define NEW_WINDOW_TRANSPARENCY         10
 #define NEW_WINDOW_USE_FONT             FALSE
-#define NEW_WINDOW_FONT_DESCR           "Sans 10"
+#define NEW_WINDOW_FONT_DESCR           "Sans 13"
 #define NEW_WINDOW_WIDTH                SIZE_NORMAL
 #define NEW_WINDOW_HEIGHT               ((gint)NEW_WINDOW_WIDTH*SIZE_FACTOR)
 
